window.Gleam.initSearch([{"doc":"melon","title":"melon","content":"[![Package Version](https://img.shields.io/hexpm/v/melon)](https://hex.pm/packages/melon)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/melon)\n![Erlang-compatible](https://img.shields.io/badge/target-erlang-a2003e)\n![JavaScript-compatible](https://img.shields.io/badge/target-javascript-f1e05a)\n\n# Melon 🍈\n\nA Gleam library for running test containers via Docker.\n\nMelon is inspired by [Testcontainers](https://testcontainers.com/) and provides an API to configure, start and stop\ncontainers.\n\nIn contrast to other libraries, Melon doesn&#39;t use the [Docker Engine API](https://docs.docker.com/engine/api/), but\nsimply searches for and uses the `docker` executable. This makes the\n[discovery methods](https://java.testcontainers.org/supported_docker_environment/#docker-environment-discovery) used by\nother libraries unnecessary. You can still use a remote Docker Engine by\n[configuring a context](https://code.visualstudio.com/docs/containers/ssh) accordingly.\n\nThis approach also makes it possible to support all non-browser targets (Erlang, Bun, Deno, and Node.js) without further\ndependencies, as consumers of this library don&#39;t need to reach for a target-specific client like\n[fetch](https://hexdocs.pm/gleam_fetch/) and [httpc](https://hexdocs.pm/gleam_httpc/) in order to communicate with the\nDocker Engine API.\n\n## Maintenance Notice 🍈\n\nAs of the 11th of August 2024, I won&#39;t be maintaining this project any longer.\n\nI don&#39;t invest time in Gleam anymore, as I encountered too many breaking changes within minor version bumps.\n\nI wish Gleam all the best, but I revert to other (enterprise-y) languages I&#39;m already used to.\n\n## Demo 🍈\n\n```gleam\nimport gleam/int\nimport gleam/io\nimport melon/container.{Megabyte, Port, Second, Tcp}\n\npub fn main() {\n  let start_result =\n    container.new(&quot;postgres:16.3-alpine3.20&quot;)\n    |&gt; container.set_memory_limit(limit: 256, unit: Megabyte)\n    |&gt; container.set_health_check_command([&quot;pg_isready&quot;, &quot;-d&quot;, &quot;morty_smith&quot;])\n    |&gt; container.set_health_check_interval(interval: 2, unit: Second)\n    |&gt; container.set_health_check_timeout(timeout: 5, unit: Second)\n    |&gt; container.set_health_check_start_period(start_period: 2, unit: Second)\n    |&gt; container.set_health_check_retries(10)\n    |&gt; container.add_exposed_port(host: &quot;127.0.0.1&quot;, port: 5432, protocol: Tcp)\n    |&gt; container.add_env(name: &quot;POSTGRES_USER&quot;, value: &quot;postgres&quot;)\n    |&gt; container.add_env(name: &quot;POSTGRES_DB&quot;, value: &quot;morty_smith&quot;)\n    |&gt; container.add_env(name: &quot;POSTGRES_PASSWORD&quot;, value: &quot;rick_sanchez&quot;)\n    |&gt; container.start()\n\n  case start_result {\n    Error(_) -&gt; io.println(&quot;Couldn&#39;t start the container :(&quot;)\n    Ok(container) -&gt;\n      case container.wait_until_healthy(container, retries: 10) {\n        Error(_) -&gt; io.println(&quot;The container is unhealthy ._.&quot;)\n        Ok(_) -&gt;\n          case container.mapped_port(container, port: 5432, protocol: Tcp) {\n            Error(_) -&gt; io.println(&quot;Couldn&#39;t find the mapped port :&lt;&quot;)\n            Ok(Port(host, port, _)) -&gt;\n              io.println(\n                &quot;The database is available on &quot;\n                &lt;&gt; host\n                &lt;&gt; &quot;:&quot;\n                &lt;&gt; int.to_string(port)\n                &lt;&gt; &quot;.&quot;,\n              )\n          }\n      }\n  }\n}\n\n```\n","url":"index.html"},{"doc":"melon","title":"melon","content":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/), and this project adheres to\n[Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## 0.4.1 - 2024-10-17\n\n### Added\n\n-   Added a maintenance notice to mark this project as canceled.\n\n### Removed\n\n-   Removed the repository.\n\n## 0.4.0 - 2024-08-02\n\n### Added\n\n-   Added `melon/container/wait_until_healthy` to wait until the given container is healthy.\n\n## 0.3.0 - 2024-07-28\n\n### Added\n\n-   Added `melon/container/set_health_check_retries` to set the health check retry count of a given container.\n-   Added `melon/container/set_health_check_start_period` to set the health check start period of a given container.\n-   Added `melon/container/set_health_check_timeout` to set the health check timeout of a given container.\n-   Added `melon/container/set_health_check_interval` to set the health check interval of a given container.\n-   Added `melon/container/set_health_check_command` to set the health check command of a given container.\n\n## 0.2.0 - 2024-07-26\n\n### Added\n\n-   Added `melon/container/set_memory_limit` to set the memory limit of a given container.\n-   Added `melon/container/set_env_file` to set the environment file of a given container.\n\n## 0.1.0 - 2024-07-23\n\n### Added\n\n-   Added `melon/container/mapped_port` to get a mapped port of a given container.\n-   Added `melon/container/stop` to stop a given container.\n-   Added `melon/container/start` to start a given container.\n-   Added `melon/container/add_env` to add an environment variable to a given container.\n-   Added `melon/container/add_exposed_port` to add an exposed port to a given container.\n-   Added `melon/container/set_working_directory` to set the working directory of a given container.\n-   Added `melon/container/set_command` to set the command of a given container.\n-   Added `melon/container/set_entrypoint` to set the entrypoint of a given container.\n-   Added `melon/container/set_user` to set the user of a given container.\n-   Added `melon/container/new` to create a new container.\n","url":"changelog.html"},{"doc":"melon","title":"melon","content":"# MIT License\n\nCopyright (c) 2024 Patrik Kühl\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated\ndocumentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the\nrights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit\npersons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the\nSoftware.\n\nTHE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE\nWARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR\nCOPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR\nOTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n","url":"license.html"},{"doc":"melon/container","title":"Container","content":"pub opaque type Container\n The type that holds information about a container.\n\nSynonyms:\nmelon/container.Container\nmelon/container Container","url":"melon/container.html#Container"},{"doc":"melon/container","title":"ContainerHealthStatusFailure","content":"pub type ContainerHealthStatusFailure {\n  CannotObtainHealthStatusOfContainerThatIsNotRunning\n  CouldNotObtainHealthStatus(reason: String)\n  ContainerIsUnhealthy\n}\n The error type to represent a reason why the health status\n of a container could not be obtained.\nCannotObtainHealthStatusOfContainerThatIsNotRunning\n\n\nCouldNotObtainHealthStatus(reason: String)\n\n\nContainerIsUnhealthy\n\n\nSynonyms:\nmelon/container.ContainerHealthStatusFailure\nmelon/container ContainerHealthStatusFailure","url":"melon/container.html#ContainerHealthStatusFailure"},{"doc":"melon/container","title":"ContainerMappedPortFailure","content":"pub type ContainerMappedPortFailure {\n  CannotObtainMappedPortOfContainerThatIsNotRunning\n  CouldNotFindMappedPort\n}\n The error type to represent a reason why a mapped port\n of a container could not be found.\nCannotObtainMappedPortOfContainerThatIsNotRunning\n\n\nCouldNotFindMappedPort\n\n\nSynonyms:\nmelon/container.ContainerMappedPortFailure\nmelon/container ContainerMappedPortFailure","url":"melon/container.html#ContainerMappedPortFailure"},{"doc":"melon/container","title":"ContainerStartFailure","content":"pub type ContainerStartFailure {\n  CouldNotStartContainer(reason: String)\n}\n The error type to represent the reason why a container\n could not be started.\nCouldNotStartContainer(reason: String)\n\n\nSynonyms:\nmelon/container.ContainerStartFailure\nmelon/container ContainerStartFailure","url":"melon/container.html#ContainerStartFailure"},{"doc":"melon/container","title":"ContainerStopFailure","content":"pub type ContainerStopFailure {\n  CannotStopContainerThatIsNotRunning\n  CouldNotStopContainer(reason: String)\n}\n The error type to represent a reason why a container\n could not be stopped.\nCannotStopContainerThatIsNotRunning\n\n\nCouldNotStopContainer(reason: String)\n\n\nSynonyms:\nmelon/container.ContainerStopFailure\nmelon/container ContainerStopFailure","url":"melon/container.html#ContainerStopFailure"},{"doc":"melon/container","title":"MemoryUnit","content":"pub type MemoryUnit {\n  Byte\n  Kilobyte\n  Megabyte\n  Gigabyte\n}\n The type to represent a memory unit.\nByte\n\n\nKilobyte\n\n\nMegabyte\n\n\nGigabyte\n\n\nSynonyms:\nmelon/container.MemoryUnit\nmelon/container MemoryUnit","url":"melon/container.html#MemoryUnit"},{"doc":"melon/container","title":"Port","content":"pub type Port {\n  Port(host: String, value: Int, protocol: PortProtocol)\n}\n The type that holds information about a port.\nPort(host: String, value: Int, protocol: PortProtocol)\n\n\nSynonyms:\nmelon/container.Port\nmelon/container Port","url":"melon/container.html#Port"},{"doc":"melon/container","title":"PortProtocol","content":"pub type PortProtocol {\n  Tcp\n  Udp\n  Sctp\n}\n The type to specify the protocol a port is exposed via.\nTcp\n\n\nUdp\n\n\nSctp\n\n\nSynonyms:\nmelon/container.PortProtocol\nmelon/container PortProtocol","url":"melon/container.html#PortProtocol"},{"doc":"melon/container","title":"TimeUnit","content":"pub type TimeUnit {\n  Second\n  Minute\n}\n The type to represent a time unit.\nSecond\n\n\nMinute\n\n\nSynonyms:\nmelon/container.TimeUnit\nmelon/container TimeUnit","url":"melon/container.html#TimeUnit"},{"doc":"melon/container","title":"add_env","content":"pub fn add_env(\n  container: Container,\n  name identifier: String,\n  value value: String,\n) -&gt; Container\n Adds an environment variable to the given container.\nSynonyms:\nmelon/container.add_env\nmelon/container add_env","url":"melon/container.html#add_env"},{"doc":"melon/container","title":"add_exposed_port","content":"pub fn add_exposed_port(\n  container: Container,\n  host host: String,\n  port port: Int,\n  protocol protocol: PortProtocol,\n) -&gt; Container\n Adds an exposed port to the given container.\nSynonyms:\nmelon/container.add_exposed_port\nmelon/container add_exposed_port","url":"melon/container.html#add_exposed_port"},{"doc":"melon/container","title":"mapped_port","content":"pub fn mapped_port(\n  container: Container,\n  port port: Int,\n  protocol protocol: PortProtocol,\n) -&gt; Result(Port, ContainerMappedPortFailure)\n Returns a mapped port of the given container.\nSynonyms:\nmelon/container.mapped_port\nmelon/container mapped_port","url":"melon/container.html#mapped_port"},{"doc":"melon/container","title":"new","content":"pub fn new(image: String) -&gt; Container\n Creates a new container using the given image.\n \n Remaining properties of the container can be configured\n via various setter functions in this module.\nSynonyms:\nmelon/container.new\nmelon/container new","url":"melon/container.html#new"},{"doc":"melon/container","title":"set_command","content":"pub fn set_command(\n  container: Container,\n  command: List(String),\n) -&gt; Container\n Sets the command of the given container.\nSynonyms:\nmelon/container.set_command\nmelon/container set_command","url":"melon/container.html#set_command"},{"doc":"melon/container","title":"set_entrypoint","content":"pub fn set_entrypoint(\n  container: Container,\n  entrypoint: String,\n) -&gt; Container\n Sets the entrypoint of the given container.\nSynonyms:\nmelon/container.set_entrypoint\nmelon/container set_entrypoint","url":"melon/container.html#set_entrypoint"},{"doc":"melon/container","title":"set_env_file","content":"pub fn set_env_file(\n  container: Container,\n  env_file: String,\n) -&gt; Container\n Sets the environment file of a given container.\nSynonyms:\nmelon/container.set_env_file\nmelon/container set_env_file","url":"melon/container.html#set_env_file"},{"doc":"melon/container","title":"set_health_check_command","content":"pub fn set_health_check_command(\n  container: Container,\n  command: List(String),\n) -&gt; Container\n Sets the health check command of the given container.\nSynonyms:\nmelon/container.set_health_check_command\nmelon/container set_health_check_command","url":"melon/container.html#set_health_check_command"},{"doc":"melon/container","title":"set_health_check_interval","content":"pub fn set_health_check_interval(\n  container: Container,\n  interval interval: Int,\n  unit unit: TimeUnit,\n) -&gt; Container\n Sets the health check interval of the given container.\nSynonyms:\nmelon/container.set_health_check_interval\nmelon/container set_health_check_interval","url":"melon/container.html#set_health_check_interval"},{"doc":"melon/container","title":"set_health_check_retries","content":"pub fn set_health_check_retries(\n  container: Container,\n  retries: Int,\n) -&gt; Container\n Sets the health check retry count of the given container.\nSynonyms:\nmelon/container.set_health_check_retries\nmelon/container set_health_check_retries","url":"melon/container.html#set_health_check_retries"},{"doc":"melon/container","title":"set_health_check_start_period","content":"pub fn set_health_check_start_period(\n  container: Container,\n  start_period start_period: Int,\n  unit unit: TimeUnit,\n) -&gt; Container\n Sets the health check start period of the given container.\nSynonyms:\nmelon/container.set_health_check_start_period\nmelon/container set_health_check_start_period","url":"melon/container.html#set_health_check_start_period"},{"doc":"melon/container","title":"set_health_check_timeout","content":"pub fn set_health_check_timeout(\n  container: Container,\n  timeout timeout: Int,\n  unit unit: TimeUnit,\n) -&gt; Container\n Sets the health check timeout of the given container.\nSynonyms:\nmelon/container.set_health_check_timeout\nmelon/container set_health_check_timeout","url":"melon/container.html#set_health_check_timeout"},{"doc":"melon/container","title":"set_memory_limit","content":"pub fn set_memory_limit(\n  container: Container,\n  limit limit: Int,\n  unit unit: MemoryUnit,\n) -&gt; Container\n Sets the memory limit of the given container.\nSynonyms:\nmelon/container.set_memory_limit\nmelon/container set_memory_limit","url":"melon/container.html#set_memory_limit"},{"doc":"melon/container","title":"set_user","content":"pub fn set_user(container: Container, user: String) -&gt; Container\n Sets the user of the given container.\nSynonyms:\nmelon/container.set_user\nmelon/container set_user","url":"melon/container.html#set_user"},{"doc":"melon/container","title":"set_working_directory","content":"pub fn set_working_directory(\n  container: Container,\n  working_directory: String,\n) -&gt; Container\n Sets the working directory of the given container.\nSynonyms:\nmelon/container.set_working_directory\nmelon/container set_working_directory","url":"melon/container.html#set_working_directory"},{"doc":"melon/container","title":"start","content":"pub fn start(\n  container: Container,\n) -&gt; Result(Container, ContainerStartFailure)\n Starts the given container.\nSynonyms:\nmelon/container.start\nmelon/container start","url":"melon/container.html#start"},{"doc":"melon/container","title":"stop","content":"pub fn stop(\n  container: Container,\n) -&gt; Result(Container, ContainerStopFailure)\n Stops the given container.\nSynonyms:\nmelon/container.stop\nmelon/container stop","url":"melon/container.html#stop"},{"doc":"melon/container","title":"wait_until_healthy","content":"pub fn wait_until_healthy(\n  container: Container,\n  retries retries: Int,\n) -&gt; Result(Container, ContainerHealthStatusFailure)\n Waits until the given container is healthy. It fails if all retries\n are exhausted.\nSynonyms:\nmelon/container.wait_until_healthy\nmelon/container wait_until_healthy","url":"melon/container.html#wait_until_healthy"},{"doc":"melon/container","title":"melon/container","content":"","url":"melon/container.html"}]);